Changelog
=========


1.0.1 (2024-03-21)
------------------

- set default value for token [Mikel Larreategi <mlarreategi@codesyntax.com>]

- fix element not having the attribute [Mikel Larreategi <mlarreategi@codesyntax.com>]

-  [Mikel Larreategi <mlarreategi@codesyntax.com>]

- [ci skip] [Mikel Larreategi <mlarreategi@codesyntax.com>]



1.0 (2024-03-21)
----------------

- Initial release.
  [erral]
